# UDTF (Beta)

::: geneva.udtf

::: geneva.transformer.UDTF
    options:
      members:
       - func
       - output_schema
       - input_columns
       - partition_by
       - partition_by_indexed_column
       - num_cpus
       - num_gpus
       - memory
       - version

::: geneva.batch_udtf

::: geneva.scalar_udtf

::: geneva.transformer.ScalarUDTF
    options:
      members:
       - func
       - output_schema
       - batch
       - input_columns
       - num_cpus
       - num_gpus
       - memory
       - version
